from flask import Flask, render_template, jsonify, request, session
from game_interface import DominoGameInterface
from domino_betting import Player

app = Flask(__name__)
app.secret_key = 'your-secret-key-here'  # Troque por uma chave secreta real

game_interface = DominoGameInterface()

@app.route('/')
def index():
    return render_template('index.html')

@app.route('/register', methods=['POST'])
def register():
    data = request.get_json()
    username = data.get('username')
    player_id = game_interface.register_player(username)
    session['player_id'] = player_id
    
    # Adicionar saldo inicial para teste
    game_interface.add_funds(player_id, 1000)
    
    return jsonify({'success': True, 'player_id': player_id})

@app.route('/create_game', methods=['POST'])
def create_game():
    data = request.get_json()
    game_type = data.get('game_type')
    bet_amount = float(data.get('bet_amount'))
    player_id = session.get('player_id')
    
    game_id = game_interface.create_game_lobby(game_type, bet_amount, player_id)
    return jsonify({'success': True, 'game_id': game_id})

@app.route('/join_game', methods=['POST'])
def join_game():
    data = request.get_json()
    game_id = data.get('game_id')
    player_id = session.get('player_id')
    
    success = game_interface.join_game(game_id, player_id)
    return jsonify({'success': success})

@app.route('/start_game', methods=['POST'])
def start_game():
    data = request.get_json()
    game_id = data.get('game_id')
    success = game_interface.start_game(game_id)
    return jsonify({'success': success})

@app.route('/game_state')
def game_state():
    game_id = request.args.get('game_id')
    player_id = session.get('player_id')
    state = game_interface.get_game_state(game_id, player_id)
    return jsonify(state)

@app.route('/make_move', methods=['POST'])
def make_move():
    data = request.get_json()
    game_id = data.get('game_id')
    piece = tuple(data.get('piece'))
    position = data.get('position')
    player_id = session.get('player_id')
    
    success = game_interface.make_move(game_id, player_id, piece, position)
    return jsonify({'success': success})

@app.route('/draw_piece', methods=['POST'])
def draw_piece():
    data = request.get_json()
    game_id = data.get('game_id')
    player_id = session.get('player_id')
    
    success = game_interface.draw_piece(game_id, player_id)
    return jsonify({'success': success})

@app.route('/create_bot_game', methods=['POST'])
def create_bot_game():
    data = request.get_json()
    bet_amount = float(data.get('bet_amount'))
    difficulty = data.get('difficulty', 'normal')
    player_id = session.get('player_id')
    
    game_id = game_interface.create_bot_game(player_id, bet_amount, difficulty)
    return jsonify({'success': True, 'game_id': game_id})

if __name__ == '__main__':
    app.run(debug=True) 